% ----------------------------------------------------------------------- %
% % incomecalc function                                                 % %
% % calculate conditional income for the three survival status          % %
% ----------------------------------------------------------------------- %

function [calc] = incomecalc(retage, gv, data, calc)

% this section is a simplified model, so not very rigirous in some aspects;
% for example, the treatment of DC pension balance;
% Dc pension balace is considered at extra income at the age of retirement;
% but if the husband / wife dies before retiring in calculations, DC pension balance disaapears;

% initialization;
income = zeros(3, 75); % approximated income by survival status (1 - 3) and age (25 - 99); only used in rho calculations;

%%%%%%%%%%%%%%%%%%%%%
% before retirement %
%%%%%%%%%%%%%%%%%%%%%
% retirement age is approximated retirement age (retage) calculated from rhocalc;
% if husband alive and before retirement, include husband's career job wage;
for age = 25 : min(retage - 1, 69);
    income(1, age - 25 + 1) = data.ftwage(age - 25 + 1, 1); % both spouses alive;
    income(2, age - 25 + 1) = data.ftwage(age - 25 + 1, 1); % only husband alive;
end;

% include spouse's wage if married couple; 
% if both spouses alive, include additional income from the wife;
% if only spouse is alive, income is wife's income;
% note: wife's wage is considered as other income in main program;
if data.spbirthyear > 0; % married couple;
    for age = 25 : 99;
        spage = age + data.birthyear - data.spbirthyear;
        if spage >= 25 && spage < 70;
            income(1, age - 25 + 1) = income(1, age - 25 + 1) + data.spwage(spage - 25 + 1, 1); % both spouses alive;
            income(3, age - 25 + 1) = data.spwage(spage - 25 + 1, 1); % only wife alive;
        end;
    end;
end;

%%%%%%%%%%%%%%%%%%%%
% after retirement %
%%%%%%%%%%%%%%%%%%%%
% include husband's DB pension benefits;
pben = data.pensben(retage - 50 + 1, 1); % DB pension benefits if retired at retage;
for age = data.penstart(retage - 50 + 1, 1) : 99; % from age at which DB pension benefits start to pay to the terminal age;
    income(1, age - 25 + 1) = income(1, age - 25 + 1) + pben; 
    income(2, age - 25 + 1) = income(2, age - 25 + 1) + pben;
    pben = pben / (1 + (1 - gv.penadjrate) * gv.inflrate); % real amount of DB pension benefits reduce at rate (1 - gv.penadjrate) * gv.inflrate each year;
end;

% include husband's DC pension balance at retage;
% include husband's DC pension balance at age of death; ???
income(1, retage - 25 + 1) = income(1, retage - 25 + 1) + data.plumpsum(retage - 50 + 1, 1); % at retage;
income(2, retage - 25 + 1) = income(2, retage - 25 + 1) + data.plumpsum(retage - 50 + 1, 1); % at retage;

% include wife's DB and DC pension;
if data.sppenstart < 99;
    
    % sppenstart: wife's DB and DC pension starting age;
    % what happens if sppenstart is bigger than 62; Her DC pension balance disappears; ???
    % sppensben: wifes DB pension benefits given her retirement age, exogenous and fixed in the model;
    % spplumpsum: wife's DC pension balance;
    % include wife's DB pension benefits;
    sppensben = data.sppensben;
    for spage = data.sppenstart : 99; % from age at which wife's DB pension benefits start to pay to the terminal age;
        age = spage + data.spbirthyear - data.birthyear; % husband's age;
        if age > 25 && age < 100;
            income(1, age - 25 + 1) = income(1, age - 25 + 1) + sppensben;
            income(3, age - 25 + 1) = income(3, age - 25 + 1) + sppensben;
        end;
        % original codes:  to my understanding, the original program is incorrect here; ???
        pben = pben / (1 + (1 - gv.penadjrate) * gv.inflrate); % real amount of DB pension benefits reduce at rate (1 - gv.penadjrate) * gv.inflrate each year;
        % revised codes;
        % sppensben = sppensben / (1 + (1 - gv.penadjrate) * gv.inflrate);  % real amount of DB pension benefits reduce at rate (1 - gv.penadjrate) * gv.inflrate each year;
    end;
    
    % include wife's DC pension balance;
    age = data.sppenstart + data.spbirthyear - data.birthyear; % husband's age when wife receives DC pension balance;
    if age >= 25 && age < 100;
        income(1, age - 25 + 1) = income(1, age - 25 + 1) + data.spplumpsum; % at sppenstart age;
        income(3, age - 25 + 1) = income(3, age - 25 + 1) + data.spplumpsum; % at sppenstart age;
    end
end

% include hosuehold's Social Security benefits;
scat = floor(calc.initialscat(retage - 50 + 1, 1)); % initial scat grid point given retirement age;

% prepare for interpolation;
if scat >= gv.nscatlim;
    scat = gv.nscatlim - 1;
end;
fs = calc.initialscat(retage - 50 + 1, 1) - scat;
    
for age = 25 : 99;
    for vcat = 1 : 3;

        if vcat < 3 && age < retage; % husband alive and working in career job;
            
            ssbenefit = calc.ssbenm(age - 25 + 1, vcat);
        
        % original codes; incorrect; out of bound when only wife alive; ???
        % else  
        %
        %     ssbenefit = (1 - fs) * calc.ssbenr(age - 50 + 1, vcat, scat) +  fs * calc.ssbenr(age - 50 + 1, vcat, scat + 1);  
        %
        % end;

        % revised codes;
        elseif age >= retage; % husband retired or died;
            
            % interpolation;
            ssbenefit = (1 - fs) * calc.ssbenr(age - 50 + 1, vcat, scat) + fs * calc.ssbenr(age - 50 + 1, vcat, scat + 1);
            
        end;
        
        income(vcat, age - 25 + 1) = income(vcat, age - 25 + 1) +  ssbenefit;
        
    end;
end;

% include other income;
% inheritances for ages 25 - 99; 
for vcat = 1 : 3; % survival status;
    for age = 25 : 99; % age;
        income(vcat, age - 25 + 1) = income(vcat, age - 25 + 1) + data.othincome(age - 25 + 1, 1); 
    end;
end;

% setup boundary;
for age = 25: 99;
    if income(1, age - 25 + 1) < 10;
        income(1, age - 25 + 1) = 10;
    end;
    if income(2, age - 25 + 1) < 10; 
        income(2, age - 25 + 1) = 10;
    end;
    if income(3, age - 25 + 1) < 10; 
        income(3, age - 25 + 1) = 10;
    end;
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% assign the values to structure variable calc for future calculations %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
calc.income = income;
















