% ----------------------------------------------------------------------- %
% % setdata function                                                    % %
% % create information for a hypothetical household                     % %
% ----------------------------------------------------------------------- %

function oridata = setdata(gv)

% ages and retirement status;
ages = [58; 60; 62; 64; 66; 68]; % ages at six survey dates;
rets = [5; 5; 1; 1; 1; 1]; % retirement status at six survey dates;
retv = [0; 0; 0; 0; 0; 0; 0; 5; 5; 5; 5; 0; 1; 1; 1; 1; 1; 1; 1; 0]; % retirement status at ages 50 - 69; 1 means fully retired, 3 means partial retired (part time work), 5 means full time work (including career job and returned full time work);

oridata.inputobs = 1; % order of observation in the final input file, keep for record only, not used in calculations; 
oridata.birthyear = 1931; % husband's birth year;
oridata.spbirthyear = 1933; % wife's birth year;
oridata.healthage = 99; % initial age of having health problem, husband; 
oridata.penjobend = 99; % age at last year of job accumulating DC pension balance; DC pension is transfered to asset at age penjobend + 1;

for surv = 1 : 6;
    oridata.age(surv, 1) = ages(surv, 1); % age at six waves of survey date;
    oridata.ret(surv, 1) = rets(surv, 1); % retirement status at six waves of survey date;
end;

for age = 50 : 69;
    oridata.retv(age - 50 + 1, 1) = retv(age - 50 + 1, 1); % retirement status vector for ages 50 - 69;
end;

% all income / wealth amounts below are in 1992 dollars
for age = 25 : 69;
    oridata.ftwage(age - 25 + 1, 1) = 30000; % husband's career job wages if working at ages 25 - 69;
end;

for age = 50 : 69;
    oridata.prwage(age - 50 + 1, 1)  =  6000; % husband's part time work wages if working at ages 50 - 69;
    oridata.secwage(age - 50 + 1, 1) = 18000; % husband's returned full time work wages if working at ages 50 - 69;
end;

for age = 25 : 69;
    if age < 62;
        oridata.spwage(age - 25 + 1, 1) = 10000; % wife's career job wages if working at spouse ages 25 - 69;
    else
        oridata.spwage(age - 25 + 1, 1) = 0;
    end;
end;

for age = 50 : 70;
    oridata.pensben(age - 50 + 1, 1) = 4000 + 200 * (age - 50); % husband's DB pension benefits if the husband retires at 50 - 70;
    
    if age < 60;
        oridata.penstart(age - 50 + 1, 1) = 60; % husband's starting age of collecting DB pension benefits if the husband retires at 50 - 59; 
        oridata.pensben(age - 50 + 1, 1) = oridata.pensben(age - 50 + 1, 1) / exp(gv.inflrate * (1- gv.penadjrate) * (60 - 60) + 0.05 * (60 - age)); % husband's DB pension benefits adjusted to starting age 60;
    else
        oridata.penstart(age - 50 + 1, 1) =  age; % husband's starting age of collecting DB pension benefits if the husband retires at 60 - 70; 
    end;
    
    oridata.plumpsum(age - 50 + 1, 1) = 500 * (age - 40); % husband's DC pension balance if the husband retires at 50 - 70;
    oridata.eowamount(age - 50 + 1, 1) = 0; % husband's early out window lump-sum amounts if the husband retires at 50 - 70;
end;

for age = 50 : 70;
    oridata.pia(age - 50 + 1, 1) = 10000 + 100 * (age - 65); % husband's primary insurance amount (PIA) if the husband retires at 50 - 70;
    oridata.ncpens(age - 50 + 1, 1) = 0; % husband's non-covered pension benefits if the husband retires at 50 - 70;
    oridata.sppia(age - 50 + 1, 1) = 4000 + 25 * (age - 65); % wifes PIA if wife retires at 50 - 70;
    oridata.spncpens(age - 50 + 1, 1) = 0; % wife's non-covered pension benefits if wife retires at 50 - 70;
end;

oridata.sppensben = 700; % wifes DB pension benefits given her retirement age, exogenous and fixed in the model;
oridata.sppenstart = 62; % wife's DB pension starting age given her retirement age;
oridata.spplumpsum = 0; % wife's DC pension balance at her retirement age;

oridata.assetwealth =  10000; % households total asset, including financial asset and land, business, and other wealth in 1992 (exclude housing);

for age = 25 : 99;
    oridata.othincome(age - 25 + 1, 1) = 0; % household's other income, such as inheritances, when husband is 25 - 99;
end;

oridata.inccat = 1; % category of households lifetime income; 1 is low, 2 is mid and 3 is high;







 
 
 
 
 
 
 
 
 