% ----------------------------------------------------------------------- %
% % simu function                                                       % %
% % simulate the model with the estimated parameters                    % % 
% ----------------------------------------------------------------------- %
  
function simu(cparm, gv, oridata, arglist) 

% print current set of parameter values;
cparm(1, 1) = gv.parm.sige;
cparm(2, 1) = gv.parm.erho;
cparm(3, 1) = gv.parm.beta0;
cparm(4, 1) = gv.parm.beta1;
cparm(5, 1) = gv.parm.beta2;
cparm(6, 1) = gv.parm.gamma0;
cparm(7, 1) = gv.parm.gamma1;
cparm(8, 1) = gv.parm.alpha;
fprintf('\n current parametes:');
fprintf('\n sige: %6.3f', cparm(1, 1));
fprintf('\n erho: %6.3f', cparm(2, 1));
fprintf('\n beta0: %6.3f', cparm(3, 1));
fprintf('\n beta1: %6.3f', cparm(4, 1));
fprintf('\n beta2: %6.3f', cparm(5, 1));
fprintf('\n gamma0: %6.3f', cparm(6, 1));
fprintf('\n gamma1: %6.3f', cparm(7, 1));
fprintf('\n alpha: %6.3f', cparm(8, 1));
fprintf('\n');


%%%%%%%%%%%%%%%%%%%
% calculate model %
%%%%%%%%%%%%%%%%%%%
% run f function to calculate results;
% use previously estimated preference parameters;
sw = 1; % if sw is 1, reset weighting matrix; if it is 0, keep the original weighting matrix;
[q, arglist] = f(sw, cparm, gv, oridata, arglist); %#ok<ASGLU>


%%%%%%%%%%%%%%%%%%
% output results %
%%%%%%%%%%%%%%%%%%
% average over all households in simulation modes;
% gv.nobs: number of observations;
% initilization;
% ret0mat: percent of simulated workers who retired from career job; or are 1) previously retired, currently in full time job; 2) currently in part time work; and 3) currently retired, by age (50 - 70)
% ret1mat: percent of simulated workers who are not currently working full time; or are 1) currently in part time work; and 2) currently retired, by age (50 - 70), gv.nobs X 21;
% ret2mat: percent of simulated workers who are currently retired, by age (50 - 70), gv.nobs X 21;
% returnft: percent of simulated workers who are previously retired or in part time work, newly return to full time work, by age (50 - 70), gv.nobs X 21;
% returnpt: percent of simulated workers who are previously retired, newly return to part time work, by age (50 - 70), gv.nobs X 21;
% newpt: percent of simulated workers who are newly enter part time work, by age (50 - 70), gv.nobs X 21;
% everreturnft: percent of simulated workers ever return to full time work after full or partial retirement, gv.nobs X 1;
% everreturnpt: percent of simulated workers ever return to part time work after full retirement, gv.nobs X 1;
% everreturn: percent of simulated workers ever return to full time work after full or partial retirement, or return to part time work after full retirement, gv.nobs X 1;
% rhocats: rho, time preference factor, distribution;
ret0mat = zeros(21,1); 
ret1mat = zeros(21,1); 
ret2mat = zeros(21,1);
returnft = zeros(21,1); 
returnpt = zeros(21,1); 
newpt = zeros(21,1);
everreturnft = 0;
everreturnpt = 0;
everreturn = 0;
rhocats = zeros(21, 1);

% generate retirement moments from structure variable arglist;
for age = 50 : 69;
    for obs = 1 : gv.nobs;
        ret0mat(age - 50 + 1, 1) = ret0mat(age - 50 + 1, 1) + arglist.ret0mat(obs, age - 50 + 1);
        ret1mat(age - 50 + 1, 1) = ret1mat(age - 50 + 1, 1) + arglist.ret1mat(obs, age - 50 + 1);
        ret2mat(age - 50 + 1, 1) = ret2mat(age - 50 + 1, 1) + arglist.ret2mat(obs, age - 50 + 1);
        returnft(age - 50 + 1, 1) = returnft(age - 50 + 1, 1) + arglist.returnft(obs, age - 50 + 1);
        returnpt(age - 50 + 1, 1) = returnpt(age - 50 + 1, 1) + arglist.returnpt(obs, age - 50 + 1);
        newpt(age - 50 + 1, 1) = newpt(age - 50 + 1, 1) + arglist.newpt(obs, age - 50 + 1);
    end;
    ret0mat(age - 50 + 1, 1) = 100 * ret0mat(age - 50 + 1, 1) / gv.nobs;
    ret1mat(age - 50 + 1, 1) = 100 * ret1mat(age - 50 + 1, 1) / gv.nobs;
    ret2mat(age - 50 + 1, 1) = 100 * ret2mat(age - 50 + 1, 1) / gv.nobs;
    returnft(age - 50 + 1, 1) = 100 * returnft(age - 50 + 1, 1) / gv.nobs;
    returnpt(age - 50 + 1, 1) = 100 * returnpt(age - 50 + 1, 1) / gv.nobs;
    newpt(age - 50 + 1, 1) = 100 * newpt(age - 50 + 1, 1) / gv.nobs;
end;

for obs = 1 : gv.nobs;
    everreturnft = everreturnft + arglist.everreturnft(obs, 1);
    everreturnpt = everreturnpt + arglist.everreturnpt(obs, 1);
    everreturn = everreturn + arglist.everreturn(obs, 1);
end;
everreturnft = 100 * everreturnft / gv.nobs;
everreturnpt = 100 * everreturnpt / gv.nobs;
everreturn = 100 * everreturn / gv.nobs;

% print tabulations;
% ret1(age) - ret1(age - 1): increased percent of simulated workers who are not in full time job; reversal jobs may be invovled;
% ret2(age) - ret2(age - 1): increased percent of simulated workers who are retired; reversal jobs may be invovled;
% 100 - ret0(age): percent of simulated workers who are in career job;
% ret0(age) - ret1(age): percent of simulated workers who previously quit career job but are currently working full time;
% ret1(age) - ret2(age): percent of simulated workers who are in part time job;
fprintf('\n\n                Percent                   Percent');
fprintf(  '\n            Pseudo-Retiring               Retired');
fprintf(  '\n           From                       From');
fprintf(  '\nAge       FT Work  Completely        FT Work  Completely');
fprintf(  '\n');
fprintf('\n 50                                  %5.1f     %5.1f',...
    ret1mat(1, 1), ret2mat(1, 1));
for age = 51 : 69;
    fprintf('\n %2d       %5.1f    %5.1f             %5.1f     %5.1f', age,...
        ret1mat(age - 50 + 1, 1) - ret1mat((age - 1) - 50 + 1, 1), ret2mat(age - 50 + 1, 1) - ret2mat((age - 1) - 50 + 1, 1), ...
        ret1mat(age - 50 + 1, 1), ret2mat(age - 50 + 1, 1));
end;

fprintf('\n\n\n                       Percent    Percent                          Percent Newly');
fprintf(    '\n                         in        Newly                   Percent   Returned');
fprintf(    '\n        Percent        FT Work    Returned       Percent    Newly   to PT Work');
fprintf(    '\nAge     in Main         after       to             in        in     Previously');
fprintf(    '\n          Job          Retiring   FT Work        PT Work   PT Work   Retired');
fprintf(    '\n');

fprintf('\n 50      %5.1f                                   %5.1f',...
    100 - ret0mat(1, 1), ret1mat(1, 1) - ret2mat(1, 1));

for age = 51 : 69;
    fprintf('\n %2d      %5.1f          %5.1f     %5.1f          %5.1f     %5.1f     %5.1f', age, ...
        100 - ret0mat(age - 50 + 1, 1), ret0mat(age - 50 + 1, 1) - ret1mat(age - 50 + 1, 1), returnft(age - 50 + 1, 1), ...
        ret1mat(age - 50 + 1, 1) - ret2mat(age - 50 + 1, 1), newpt(age - 50 + 1, 1), returnpt(age - 50 + 1, 1));
end;

fprintf('\n\nPercent returning to full time work after full or partial retirement: %5.1f', everreturnft);
fprintf('\nPercent returning to part time work after full retirement: %5.1f', everreturnpt);
fprintf('\nPercent returning to full time work after full or partial retirement');
fprintf('\n  or returning to part time work after full retirement: %5.1f', everreturn);


% print distribution of time preferences;
for obs = 1 : gv.nobs;
    if arglist.rvec(obs, 1) < 0; % rho is smaller than 0, assign to the lowest category;
        rhocats(1, 1) = rhocats(1, 1) + 1;
    else
        if arglist.rvec(obs, 1) > 1; % rho is larger than 1, assign to the highest category;
            rhocats(21, 1) = rhocats(21, 1) + 1;
        else
            cat = floor(20 * arglist.rvec(obs, 1)); % between 0 and 1; 0.05 each category;
            rhocats(cat, 1) = rhocats(cat, 1) + 1;
        end;
    end;
end;
fprintf('\n\nDistribution of time preference rates\n');
for i = 1 : 5;
    for j = 1 : 5;
        if j < 5 || i == 1
            fprintf('   %5.2f %5d', (0.05 * (5 * (j - 1) + (i - 1))), rhocats(5 * (j - 1) + i, 1));
        end;
    end;
end;
fprintf('\n');





















